@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::js::duration::float_secs;
 
-our $DATE = '2016-05-18'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2016-05-19'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,6 +10,7 @@ use warnings;
 sub meta {
     +{
         enable_by_default => 1,
+        prio => 50,
     };
 }
 
@@ -35,7 +36,7 @@ sub coerce {
 }
 
 1;
-# ABSTRACT: Coerce duration from float (assumed to be number of seconds)
+# ABSTRACT: Coerce duration from number (assumed to be number of seconds)
 
 __END__
 
@@ -45,11 +46,11 @@ __END__
 
 =head1 NAME
 
-Data::Sah::Coerce::js::duration::float_secs - Coerce duration from float (assumed to be number of seconds)
+Data::Sah::Coerce::js::duration::float_secs - Coerce duration from number (assumed to be number of seconds)
 
 =head1 VERSION
 
-This document describes version 0.005 of Data::Sah::Coerce::js::duration::float_secs (from Perl distribution Data-Sah-Coerce), released on 2016-05-18.
+This document describes version 0.006 of Data::Sah::Coerce::js::duration::float_secs (from Perl distribution Data-Sah-Coerce), released on 2016-05-19.
 
 =for Pod::Coverage ^(meta|coerce)$
 
