@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::js::duration::str_iso8601;
 
-our $DATE = '2016-05-18'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2016-05-19'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,6 +10,7 @@ use warnings;
 sub meta {
     +{
         enable_by_default => 1,
+        prio => 50,
     };
 }
 
@@ -34,7 +35,7 @@ sub coerce {
     # XXX i need a trick to avoid doing regex match twice
 
     # approximation
-    $res->{expr_coerce} = "(function(_m) { _m = $expr_re_match; return ((_m[1]||0)*365.25*86400 + (_m[2]||0)*30.4375*86400 + (_m[3]||0)*7*86400 + (_m[4]||0)*86400 + (_m[5]||0)*3600 + (_m[6]||0)*60 + (_m[7]||0)) })()";
+    $res->{expr_coerce} = "(function(_m) { _m = $expr_re_match; return ((_m[1]||0)*365.25*86400 + (_m[2]||0)*30.4375*86400 + (_m[3]||0)*7*86400 + (_m[4]||0)*86400 + (_m[5]||0)*3600 + (_m[6]||0)*60 + (_m[7]||0)*1) })()";
 
     $res;
 }
@@ -54,7 +55,7 @@ Data::Sah::Coerce::js::duration::str_iso8601 - Coerce duration from (subset of)
 
 =head1 VERSION
 
-This document describes version 0.005 of Data::Sah::Coerce::js::duration::str_iso8601 (from Perl distribution Data-Sah-Coerce), released on 2016-05-18.
+This document describes version 0.006 of Data::Sah::Coerce::js::duration::str_iso8601 (from Perl distribution Data-Sah-Coerce), released on 2016-05-19.
 
 =head1 DESCRIPTION
 
