@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::date::obj_TimeMoment;
 
-our $DATE = '2016-05-18'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2016-05-19'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,6 +10,7 @@ use warnings;
 sub meta {
     +{
         enable_by_default => 1,
+        prio => 50,
     };
 }
 
@@ -29,7 +30,7 @@ sub coerce {
         "$dt\->isa('Time::Moment')",
     );
 
-    if ($coerce_to eq 'int(epoch)') {
+    if ($coerce_to eq 'float(epoch)') {
         $res->{expr_coerce} = "$dt\->epoch";
     } elsif ($coerce_to eq 'DateTime') {
         $res->{modules}{'DateTime'} //= 0;
@@ -38,7 +39,7 @@ sub coerce {
         $res->{expr_coerce} = $dt;
     } else {
         die "BUG: Unknown coerce_to value '$coerce_to', ".
-            "please use int(epoch), DateTime, or Time::Moment";
+            "please use float(epoch), DateTime, or Time::Moment";
     }
 
     $res;
@@ -59,7 +60,7 @@ Data::Sah::Coerce::perl::date::obj_TimeMoment - Coerce date from Time::Moment ob
 
 =head1 VERSION
 
-This document describes version 0.005 of Data::Sah::Coerce::perl::date::obj_TimeMoment (from Perl distribution Data-Sah-Coerce), released on 2016-05-18.
+This document describes version 0.006 of Data::Sah::Coerce::perl::date::obj_TimeMoment (from Perl distribution Data-Sah-Coerce), released on 2016-05-19.
 
 =for Pod::Coverage ^(meta|coerce)$
 
