@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::date::str_iso8601;
 
-our $DATE = '2016-05-18'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2016-05-19'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,6 +11,7 @@ sub meta {
     +{
         enable_by_default => 1,
         might_die => 1, # we match any (YYYY-MM-DD... string, so the conversion to date might fail on invalid dates)
+        prio => 50,
     };
 }
 
@@ -32,7 +33,7 @@ sub coerce {
     $res->{modules}{"Time::Local"} //= 0;
 
     my $code_epoch = '$4 ? ($8 ? Time::Local::timegm($7, $6, $5, $3, $2-1, $1-1900) : Time::Local::timelocal($7, $6, $5, $3, $2-1, $1-1900)) : Time::Local::timelocal(0, 0, 0, $3, $2-1, $1-1900)';
-    if ($coerce_to eq 'int(epoch)') {
+    if ($coerce_to eq 'float(epoch)') {
         $res->{expr_coerce} = $code_epoch;
     } elsif ($coerce_to eq 'DateTime') {
         $res->{modules}{"DateTime"} //= 0;
@@ -42,7 +43,7 @@ sub coerce {
         $res->{expr_coerce} = "Time::Moment->from_epoch($code_epoch)";
     } else {
         die "BUG: Unknown coerce_to value '$coerce_to', ".
-            "please use int(epoch), DateTime, or Time::Moment";
+            "please use float(epoch), DateTime, or Time::Moment";
     }
 
     $res;
@@ -63,7 +64,7 @@ Data::Sah::Coerce::perl::date::str_iso8601 - Coerce date from (a subset of) ISO8
 
 =head1 VERSION
 
-This document describes version 0.005 of Data::Sah::Coerce::perl::date::str_iso8601 (from Perl distribution Data-Sah-Coerce), released on 2016-05-18.
+This document describes version 0.006 of Data::Sah::Coerce::perl::date::str_iso8601 (from Perl distribution Data-Sah-Coerce), released on 2016-05-19.
 
 =head1 DESCRIPTION
 
